@@ -528,7 +528,7 @@ class BatteryStateWithoutLastEvent(BaseStateWithoutLastEvent, BatterySetEvent):
 
 
 class FrameState(MotionState):
-    frame_id: str
+    frameData: "FrameData"
     metadata: "FrameMetadata"
 
 
@@ -673,8 +673,8 @@ class CameraSource(Protocol):
     async def get_stream_info(self) -> Optional[StreamInfo]: ...
 
 
-ImageOutputFormat = Literal["rgb", "rgba", "gray"]
 ImageInputFormat = Literal["yuv", "rgb", "rgba", "gray"]
+ImageOutputFormat = Literal["rgb", "rgba", "gray"]
 
 
 class ImageFormat(TypedDict):
@@ -717,11 +717,16 @@ class FrameMetadata(TypedDict):
     origHeight: int
 
 
+class FrameData(TypedDict):
+    frameId: str
+    timestamp: int
+
+
 class ImageInformation(TypedDict):
     width: int
     height: int
     channels: Literal[1, 3, 4]
-    format: ImageOutputFormat
+    format: ImageInputFormat
 
 
 class FrameBuffer(TypedDict):
@@ -735,7 +740,7 @@ class FrameImage(TypedDict):
 
 
 class VideoFrame(Protocol):
-    frame_id: str
+    frame_data: FrameData
     metadata: FrameMetadata
     input_width: int
     input_height: int
